@@ -1,5 +1,5 @@
 from enum import Enum
-from sdgs_tools.dashboard.utils import make_str_to_enum
+from sdgs_tools.dashboard.utils import make_str_to_enum, make_dunder_str
 
 MAPPING = {
     "Petani Pemilik Lahan": "1",
@@ -40,3 +40,4 @@ class PekerjaanUtama(Enum):
     LAINNYA = "other"
 
     from_str = classmethod(make_str_to_enum(MAPPING))
+    __str__ = make_dunder_str(MAPPING)
