@@ -1,5 +1,5 @@
 from enum import Enum
-from sdgs_tools.dashboard.utils import make_str_to_enum
+from sdgs_tools.dashboard.utils import make_str_to_enum, make_dunder_str
 
 MAPPING = {
     "Padi": "1",
@@ -96,3 +96,4 @@ class SumberPenghasilan(Enum):
     LAINNYA = "other"
 
     from_str = classmethod(make_str_to_enum(MAPPING, "43"))
+    __str__ = make_dunder_str(MAPPING)
