@@ -32,15 +32,15 @@ MAPPING_VALUE = {
 
 @attr.dataclass
 class AksesPendidikan:
-    paud: Akses
-    tk: Akses
-    sd: Akses
-    smp: Akses
-    sma: Akses
-    pt: Akses
-    pesantren: Akses
-    seminari: Akses
-    lainnya: Akses
+    paud: Akses = attr.field(default=attr.Factory(Akses))
+    tk: Akses = attr.field(default=attr.Factory(Akses))
+    sd: Akses = attr.field(default=attr.Factory(Akses))
+    smp: Akses = attr.field(default=attr.Factory(Akses))
+    sma: Akses = attr.field(default=attr.Factory(Akses))
+    pt: Akses = attr.field(default=attr.Factory(Akses))
+    pesantren: Akses = attr.field(default=attr.Factory(Akses))
+    seminari: Akses = attr.field(default=attr.Factory(Akses))
+    lainnya: Akses = attr.field(default=attr.Factory(Akses))
 
     def todict(self) -> Dict[str, Dict[str, str]]:
         data: Dict[str, Dict[str, str]] = dict()
@@ -55,3 +55,8 @@ class AksesPendidikan:
         for name, args in MAPPING_VALUE.items():
             data[name] = Akses.from_cols(ws, row, *args)
         return data
+
+    def save(self, ws: Worksheet, row: int):
+        for name, args in MAPPING_VALUE.items():
+            akses: Akses = getattr(self, name)
+            akses.save(ws, row, *args)
