@@ -24,11 +24,11 @@ MAPPING_VALUE = {
 
 @attr.dataclass
 class AksesTenagaKesehatan:
-    spesialis: Akses
-    dokter: Akses
-    bidan: Akses
-    nakes: Akses
-    dukun: Akses
+    spesialis: Akses = attr.field(default=attr.Factory(Akses))
+    dokter: Akses = attr.field(default=attr.Factory(Akses))
+    bidan: Akses = attr.field(default=attr.Factory(Akses))
+    nakes: Akses = attr.field(default=attr.Factory(Akses))
+    dukun: Akses = attr.field(default=attr.Factory(Akses))
 
     def todict(self) -> Dict[str, Dict[str, str]]:
         data: Dict[str, Dict[str, str]] = dict()
@@ -43,3 +43,8 @@ class AksesTenagaKesehatan:
         for name, args in MAPPING_VALUE.items():
             data[name] = Akses.from_cols(ws, row, *args)
         return data
+
+    def save(self, ws: Worksheet, row: int):
+        for name, args in MAPPING_VALUE.items():
+            akses: Akses = getattr(self, name)
+            akses.save(ws, row, *args)
