@@ -1,5 +1,5 @@
 import attr
-from typing import Dict, Optional
+from typing import Dict, List, Optional
 
 from .enums import YaTidak
 
@@ -27,6 +27,16 @@ class BantuanPemerintah:
     bantuan_pendidikan_anak: YaTidak = YaTidak.TIDAK
     lainnya: YaTidak = YaTidak.TIDAK
 
+    def __str__(self):
+        values: List[str] = list()
+        for key, name in MAPPING.items():
+            value = getattr(self, name)
+            if value == YaTidak.YA:
+                values.append(key)
+        if not values:
+            return ""
+        return ", ".join(values)
+
     def todict(self) -> Dict[str, str]:
         return {
             "1": self.blt_dd.value,
@@ -43,6 +53,8 @@ class BantuanPemerintah:
     def from_str(cls, val: Optional[str], t=None) -> "BantuanPemerintah":
         if not val:
             return cls()
+        elif isinstance(val, dict):
+            return cls.from_dict(val)
         data: Dict[str, YaTidak] = dict()
         for key, name in MAPPING.items():
             if key in val:
@@ -50,3 +62,13 @@ class BantuanPemerintah:
             else:
                 data[name] = YaTidak.TIDAK
         return cls(**data)
+
+    @classmethod
+    def from_dict(cls, val: Dict[str, str]) -> "BantuanPemerintah":
+        data: Dict[str, YaTidak] = dict()
+        for name, value in val.items():
+            if value == "Ya":
+                data[name] = YaTidak.YA
+            else:
+                data[name] = YaTidak.TIDAK
+        return cls(**data)
