@@ -1,5 +1,5 @@
 from enum import Enum
-from sdgs_tools.dashboard.utils import make_str_to_enum
+from sdgs_tools.dashboard.utils import make_str_to_enum, make_dunder_str
 
 MAPPING = {
     "Ada, berfungsi": "1",
@@ -14,3 +14,4 @@ class Jendela(Enum):
     TIDAK_ADA = "3"
 
     from_str = classmethod(make_str_to_enum(MAPPING, "1"))
+    __str__ = make_dunder_str(MAPPING)
